@@ -50,11 +50,11 @@ class FlaskSQLService(object):
         options = self.extract_options(app)
         self.collect_all_models(app)
         database_class = app.config.get("DATABASE_CLASS", None) or Database
-        self.db = database_class(**options)
-        self._add_session_handlers(app, options.get(
+        db: "Database" = database_class(**options)
+        self._add_session_handlers(app, db, options.get(
             "autoflush", None), options.get("expire_on_commit", None),)
-        self._add_commands(app, options.get("SQL_CLI_GROUP", "sql"))
-        app.extensions[app.config.get("SQL_EXTENSION_KEY", "sql-db")] = self
+        self._add_commands(app, db, options.get("SQL_CLI_GROUP", "sql"))
+        app.extensions[app.config.get("SQL_EXTENSION_KEY", "sql-db")] = db
 
     def extract_options(self, app: "Flask"):
         options = {}
@@ -103,10 +103,10 @@ class FlaskSQLService(object):
             if isinstance(mod, str):
                 import_string(mod)
 
-    def _add_session_handlers(self, app, autoflush=None, expire_on_commit=None):
+    def _add_session_handlers(self, app: "Flask", db: "Database", autoflush=None, expire_on_commit=None):
         @app.before_request
         def create_dbsession():
-            g.dbsession = self.db.session(
+            g.dbsession = db.session(
                 autoflush=autoflush, expire_on_commit=expire_on_commit
             )
 
@@ -117,18 +117,18 @@ class FlaskSQLService(object):
             g.dbsession.close()  # type: ignore
             return response_or_exc
 
-    def _add_commands(self, app: "Flask", group_name: str):
+    def _add_commands(self, app: "Flask", db: "Database", group_name: str):
         group = AppGroup(group_name)
 
         @group.command()
         @with_appcontext
         def create_all():
             self.collect_all_models(app)
-            self.db.create_all()
+            db.create_all()
 
         @group.command()
         @with_appcontext
         def drop_all():
-            self.db.drop_all()
+            db.drop_all()
 
         app.cli.add_command(group)
